@@ -161,8 +161,27 @@ where
 
             // loop over each folder
             for (folder, exercises_in_folder) in &grouped {
+                let exercises_in_folder: Vec<_> = exercises_in_folder.collect();
+
+                let folder_statuses: Vec<_> =
+                    exercises_in_folder.iter().map(|e| e.status()).collect();
+                let contains_not_started = folder_statuses.contains(&Status::NotStarted);
+                let contains_started = folder_statuses.contains(&Status::Started);
+                let contains_completed = folder_statuses.contains(&Status::Completed);
+
+                let folder_status =
+                    match (contains_not_started, contains_started, contains_completed) {
+                        // Folder contains no started or completed exercises
+                        (true, false, false) => Status::NotStarted,
+                        // Folder contains at least one not started exercises while not all beign not started
+                        (true, _, _) => Status::Started,
+                        // Folder contains at least one started exercise amidst only completed exercises
+                        (false, true, _) => Status::Started,
+                        (false, false, true) => Status::Completed,
+                        (false, false, false) => unreachable!("no exercises in folder"),
+                    };
                 // render the week line always in non highlight mode
-                render.render_item(folder, false)?;
+                render.render_item(&format!("{} {}", folder, folder_status), false)?;
 
                 // if the week is the selected week
                 if selected_exercise.folder_name() == folder {
